@@ -387,6 +387,8 @@ app_ui <- function() {
                             tabName = "IRTwright",
                             fluidPage(column(8,
                                              box(title = "WrightMap", solidHeader = TRUE, status = "info",
+                                                 tags$b("Note: "), "You can only draw WrightMap for Rasch and partial credit models.",
+                                                 br(),br(),
                                                  uiOutput("IRT_wright1")%>%
                                                    box_show_theme(),
                                                  width = 12)),
@@ -399,6 +401,11 @@ app_ui <- function() {
                                                  sliderInput(inputId = "IRT_wright_map_p_size",label = "The size of points.",
                                                              min = 1,max = 7,step = 0.5,value = 3),
                                                  br(),
+                                                 selectInput(inputId = "IRT_point_label",
+                                                             label = "The label of the point.",
+                                                             choices = list("Numeric","Column names"),
+                                                             selected = "Numeric"),
+                                                 br(),
                                                  sliderInput(inputId = "IRT_wright_p_width",label = "The width of right plot.",
                                                              min = 1, max = 5, value = 1.618, step = 0.25),
                                                  submitButton( "Updata plot")),
@@ -422,7 +429,7 @@ app_ui <- function() {
                                                              label = "Select column number",
                                                              choices = list("2","3","4","5","6","7"),
                                                              selected = "4"),
-                                                 submitButton( "Updata plot")),
+                                                 submitButton( "Updata results")),
                                              box(title = "Download figure",solidHeader = TRUE,status = "success",width = 12,
                                                  downloadButton(outputId = "IRT_ICCfile", label = "Download"))))
                           ),
@@ -434,6 +441,19 @@ app_ui <- function() {
                                                    box_show_theme(),
                                                  width = 12)),
                                       column(4,
+                                             box(title = "Adjust plot", solidHeader = TRUE,status = "warning",width = 12,
+                                                 selectInput(inputId = "IRTiic_scale",label = "Free or fixed y axis",
+                                                             choices = list("Free","Fixed"),selected = "Free"),
+                                                 br(),
+                                                 sliderInput(inputId = "wrap_height_iic", label = "Select height",
+                                                             min = 300, max = 1800,value = 400,step = 30),
+                                                 br(),
+                                                 selectInput(inputId = "wrap_ncol_iic",
+                                                             label = "Select column number",
+                                                             choices = list("2","3","4","5","6","7"),
+                                                             selected = "4"),
+
+                                                 submitButton( "Updata results")),
                                              box(title = "Download figure",solidHeader = TRUE,status = "success",width = 12,
                                                  downloadButton(outputId = "IRT_IICfile", label = "Download"))))
                           ),
@@ -604,6 +624,8 @@ app_ui <- function() {
                             tabName = "MIRTwright",
                             fluidPage(column(8,
                                              box(title = "WrightMap", solidHeader = TRUE, status = "info",width = 12,
+                                                 tags$b("Note: "), "You can only draw WrightMap for Rasch and partial credit models.",
+                                                 br(),br(),
                                                  uiOutput("MIRT_wright1")%>%
                                                    box_show_theme() )),
                                       column(4,
@@ -615,6 +637,11 @@ app_ui <- function() {
                                                  sliderInput(inputId = "MIRT_wright_map_p_size",label = "The size of points.",
                                                              min = 1,max = 7,step = 0.5,value = 3),
                                                  br(),
+                                                 selectInput(inputId = "MIRT_point_label",
+                                                             label = "The label of the point.",
+                                                             choices = list("Numeric","Column names"),
+                                                             selected = "Numeric"),
+                                                 br(),
                                                  sliderInput(inputId = "MIRT_wright_p_width",label = "The width of right plot.",
                                                              min = 1, max = 5, value = 1.618, step = 0.25),
                                                  uiOutput("MIRT_wright_dim_select"),
@@ -640,7 +667,7 @@ app_ui <- function() {
                                                              label = "Select column number",
                                                              choices = list("2","3","4","5","6","7"),
                                                              selected = "4"),
-                                                 submitButton( "Updata plot")),
+                                                 submitButton( "Updata results")),
                                              box(title = "Download figure",solidHeader = TRUE,status = "success",width = 12,
                                                  downloadButton(outputId = "MIRT_ICCfile", label = "Download"))))
                           ),
@@ -652,6 +679,19 @@ app_ui <- function() {
                                                    box_show_theme(),
                                                  width = 12)),
                                       column(4,
+                                             box(title = "Adjust plot", solidHeader = TRUE,status = "warning",width = 12,
+                                                 selectInput(inputId = "MIRTiic_scale",label = "Free or fixed y axis",
+                                                             choices = list("Free","Fixed"),selected = "Free"),
+                                                 br(),
+                                                 sliderInput(inputId = "MIRT_wrap_height_iic", label = "Select height",
+                                                             min = 300,max = 1800,step = 30,value = 400),
+                                                 br(),
+                                                 selectInput(inputId = "MIRT_wrap_ncol_iic",
+                                                             label = "Select column number",
+                                                             choices = list("2","3","4","5","6","7"),
+                                                             selected = "4"),
+
+                                                 submitButton( "Updata results")),
                                              box(title = "Download figure",solidHeader = TRUE,status = "success",width = 12,
                                                  downloadButton(outputId = "MIRT_IICfile", label = "Download"))))
                           ),
